<?php

namespace App\Repository;

use App\Entity\GeoImage;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Persistence\ManagerRegistry;

/**
 * @extends ServiceEntityRepository<GeoImage>
 */
class GeoImageRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, GeoImage::class);
    }

    /**
     * Returns all geoimages with associated geometry (polygon)
     * as GeoJSON
     * @return GeoImage[]
     */
    public function findAllWithGeometry()
    {
        $conn = $this->getEntityManager()->getConnection();

        $sql = "SELECT
                id,
                filename,
                ST_AsGeoJSON(poligono) as polygon
            FROM geo_immagine_catasto
        ";

        $results = $conn->executeQuery($sql)
            ->fetchAllAssociative();

        $entities = [];
        foreach ($results as $result) {
            $geoimage = new GeoImage();
            $geoimage->setId($result['id']);
            $geoimage->setFilename($result['filename']);
            $geoimage->setPolygon($result['polygon']);
            $entities[] = $geoimage;
        }

        return $entities;
    }

    //    /**
    //     * @return GeoImage[] Returns an array of GeoImage objects
    //     */
    //    public function findByExampleField($value): array
    //    {
    //        return $this->createQueryBuilder('g')
    //            ->andWhere('g.exampleField = :val')
    //            ->setParameter('val', $value)
    //            ->orderBy('g.id', 'ASC')
    //            ->setMaxResults(10)
    //            ->getQuery()
    //            ->getResult()
    //        ;
    //    }

    //    public function findOneBySomeField($value): ?GeoImage
    //    {
    //        return $this->createQueryBuilder('g')
    //            ->andWhere('g.exampleField = :val')
    //            ->setParameter('val', $value)
    //            ->getQuery()
    //            ->getOneOrNullResult()
    //        ;
    //    }
}
